*DECK NSSCO
      SUBROUTINE NSSCO(NVOL,NMIX,KEL,MAT,XX,IQFR,QFR,DIFF,COEF)
*
*-----------------------------------------------------------------------
*
*Purpose:
* Compute the mesh centered finite difference coefficients in element K.
*
*Copyright:
* Copyright (C) 2002 Ecole Polytechnique de Montreal
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
* version 2.1 of the License, or (at your option) any later version
*
*Author(s): A. Hebert
*
*Parameters: input
* NVOL    total number of nodes.
* NMIX    number of material mixtures.
* KEL     index of node under consideration.
* MAT     mixture index assigned to each element.
* DIF     directional diffusion coefficients.
* XX      X-directed mesh spacings.
* KN      element-ordered unknown list:
*         .GT.0: neighbour index;
*         =-1:  void/albedo boundary condition;
*         =-2:  reflection boundary condition;
*         =-3:  ZERO flux boundary condition;
*         =-4:  SYME boundary condition (axial symmetry).
* QFR     element-ordered boundary conditions.
*
*Parameters: output
* COEF    mesh centered finite difference coefficients.
*
*-----------------------------------------------------------------------
*
*----
*  SUBROUTINE ARGUMENTS
*----
      INTEGER :: NVOL,NMIX,KEL,MAT(NVOL),IQFR(2)
      REAL :: XX(NVOL),QFR(2),DIFF(NMIX)
      REAL :: COEF(2)
      DHARM(X1,X2,DIF1,DIF2)=2.0*DIF1*DIF2/(X1*DIF2+X2*DIF1)
      !
      IBM=MAT(KEL)
      DX=XX(KEL)
      KK1=IQFR(1)
      KK2=IQFR(2)
      ! X- SIDE:
      IF(KK1 == 0) THEN
        COEF(1)=DHARM(DX,XX(KEL-1),DIFF(IBM),DIFF(MAT(KEL-1)))
      ELSEIF((KK1 > 0).OR.(KK1 == -1)) THEN
        COEF(1)=DHARM(DX,DX,DIFF(IBM),DX*QFR(1)/2.0)
      ELSEIF(KK1 == -2) THEN
        COEF(1)=0.0
      ELSEIF(KK1 == -3) THEN
        COEF(1)=2.0*DHARM(DX,DX,DIFF(IBM),DIFF(IBM))
      ENDIF
      ! X+ SIDE:
      IF(KK2 == 0) THEN
        COEF(2)=DHARM(DX,XX(KEL+1),DIFF(IBM),DIFF(MAT(KEL+1)))
      ELSEIF((KK2 > 0).OR.(KK2 == -1)) THEN
        COEF(2)=DHARM(DX,DX,DIFF(IBM),DX*QFR(2)/2.0)
      ELSEIF(KK2 == -2) THEN
        COEF(2)=0.0
      ELSEIF(KK2 == -3) THEN
        COEF(2)=2.0*DHARM(DX,DX,DIFF(IBM),DIFF(IBM))
      ELSEIF(KK2 == -4) THEN
        IF(KK1 == -4) CALL XABORT('NSSCO: INCONSISTENT SYME (1).')
        COEF(2)=COEF(1)
      ENDIF
      !
      IF(KK1 == -4) THEN
        IF(KK2 == -4) CALL XABORT('NSSCO: INCONSISTENT SYME (2).')
        COEF(1)=COEF(2)
      ENDIF
      END SUBROUTINE NSSCO
