*DECK NSSMXX
      SUBROUTINE NSSMXX(LX1,NMIX,MAT,XX,IQFR,QFR,DIFF,DRIFT,SIGT,AGGX)
*
*-----------------------------------------------------------------------
*
*Purpose:
* Assembly of system matrices for coarse mesh finite differences with
* nodal correction.
*
*Copyright:
* Copyright (C) 2022 Ecole Polytechnique de Montreal
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
* version 2.1 of the License, or (at your option) any later version
*
*Author(s): A. Hebert
*
*Parameters: input
* LX1     number of nodes.
* NMIX    number of mixtures.
* MAT     node mixtures.
* XX      node widths.
* IQFR    boundary conditions.
* QFR     albedo functions.
* DIFF    diffusion coefficients.
* DRIFT   drift coefficients.
* SIGT    removal macroscopic cross section.
*
*Parameters: output
* AGGX    matrix corresponding to the divergence (i.e leakage) and
*         removal terms.
*
*-----------------------------------------------------------------------
*
*----
*  SUBROUTINE ARGUMENTS
*----
        INTEGER LX1,NMIX,MAT(LX1),IQFR(6,LX1)
        REAL XX(LX1),QFR(6,LX1),DIFF(NMIX),DRIFT(2,LX1),SIGT(NMIX),
     1  AGGX(LX1,LX1)
        REAL COEF(2),CODR(2)
*
        AGGX(:LX1,:LX1)=0.D0
        DO KEL=1,LX1
          CALL NSSCO(LX1,NMIX,KEL,MAT,XX,IQFR(1,KEL),QFR(1,KEL),DIFF,
     1    COEF)
          CODR(1)=DRIFT(1,KEL)
          CODR(2)=DRIFT(2,KEL)
          KK1=IQFR(1,KEL)
          IF(KK1 == -4) THEN
            KK1=LX1
          ELSE IF(KK1 == 0) THEN
            KK1=KEL-1
          ENDIF
          KK2=IQFR(2,KEL)
          IF(KK2 == -4) THEN
            KK2=1
          ELSE IF(KK2 == 0) THEN
            KK2=KEL+1
          ENDIF
          IF(IQFR(1,KEL) == 0) THEN
            AGGX(KEL,KK1)=AGGX(KEL,KK1)-COEF(1)+CODR(1)
          ENDIF
          IF(IQFR(2,KEL) == 0) THEN
            AGGX(KEL,KK2)=AGGX(KEL,KK2)-COEF(2)-CODR(2)
          ENDIF
          AGGX(KEL,KEL)=AGGX(KEL,KEL)+COEF(1)+CODR(1)+COEF(2)-CODR(2)+
     1    SIGT(MAT(KEL))*XX(KEL)
        ENDDO
        RETURN
      END SUBROUTINE NSSMXX
